@@ -3,7 +3,7 @@ import logging
 import pytest
 from tortoise.functions import Count
 from xync_schema.enums import ExStatus, ExAction, UserStatus
-from xync_schema.models import Ex, ExStat, Ad, Coin, Cur, Pmcur, Cred, CredEx, Actor, Person
+from xync_schema.models import Ex, ExStat, Ad, Coin, Cur, PmCur, Cred, CredEx, Actor, Person
 from xync_schema.xtype import BaseAd
 
 from xync_client.Abc.BaseTest import BaseTest
@@ -32,9 +32,9 @@ class TestAgent(BaseTest):
     # 26
     async def test_cred_new(self, clients: list[tuple[BaseAgentClient, BaseAgentClient]]):
         for maker, taker in clients:
-            pmcur = await Pmcur.filter(pm__pmexs__ex=taker.actor.ex, cur__ticker="RUB", pm__norm="payeer").first()
+            pmcur = await PmCur.filter(pm__pmexs__ex=taker.actor.ex, cur__ticker="RUB", pm__norm="payeer").first()
             cred = await Cred.create(person_id=taker.actor.person_id, name="Tst", detail="79990001234", pmcur=pmcur)
-            # await cred.banks.add(await PmexBank.get(exid="mts"), await PmexBank.get(exid="sberbankru"))
+            # await cred.banks.add(await PmExBank.get(exid="mts"), await PmExBank.get(exid="sberbankru"))
             cred_new: CredEx = await taker.cred_new(cred)
             ok = isinstance(cred_new, CredEx)
             t, _ = await ExStat.update_or_create({"ok": ok}, ex=taker.actor.ex, action=ExAction.cred_new)
@@ -159,7 +159,7 @@ class TestAgent(BaseTest):
     async def test_ad_del(self, clients: list[tuple[BaseAgentClient, BaseAgentClient]]):
         for maker, taker in clients:
             my_ads: ListOfDicts = await taker.my_ads()
-            ad_del: bool = await taker.ad_del(offer_id=my_ads[0]["id"])
+            ad_del: bool = await taker.ad_del(ad_id=my_ads[0]["id"])
             t, _ = await ExStat.update_or_create({"ok": ad_del}, ex=taker.actor.ex, action=ExAction.ad_del)
             assert t.ok, "No add new ad"
             logging.info(f"{taker.actor.ex.name}:{ExAction.ad_del.name} - ok")
