@@ -84,13 +84,13 @@ class TestEx(BaseTest):
     #         logging.info(f"{client.ex.name}: {ExAction.cur_pms_map.name} - ok")
 
     # 22
-    # async def test_coins(self, clients: list[BaseExClient]):
-    #     for client in clients:
-    #         coins: dict[str, CoinEx] = await client.coins()
-    #         ok = self.is_dict_of_objects(coins, CoinEx)
-    #         t, _ = await ExStat.update_or_create({"ok": ok}, ex=client.ex, action=ExAction.coins)
-    #         assert t.ok, "No coins"
-    #         logging.info(f"{client.ex.name}: {ExAction.coins.name} - ok")
+    async def test_coins(self, clients: list[BaseExClient]):
+        for client in clients:
+            coins: dict[str, models.CoinEx] = await client.coins()
+            ok = self.is_dict_of_objects(coins, models.CoinEx)
+            t, _ = await models.ExStat.update_or_create({"ok": ok}, ex=client.ex, action=ExAction.coins)
+            assert t.ok, "No coins"
+            logging.info(f"{client.ex.name}: {ExAction.coins.name} - ok")
 
     # # 23
     # async def test_pairs(self, clients: list[BaseExClient]):
