@@ -26,7 +26,7 @@ async def main():
     ex = await Ex.get(name="BitPapa")
     cl = ExClient(ex)
     _ads = await cl.ads(2, 11, True)
-    await cl.set_pmcurs()
+    await cl.set_pms()
     await cl.set_coins()
     _cr = await cl.curs()
     _cn = await cl.coins()
