@@ -11,7 +11,6 @@ from decimal import Decimal
 from playwright.async_api import async_playwright
 from pyro_client.client.file import FileClient
 from tortoise.transactions import in_transaction
-from xync_schema.models import CredEx
 
 from xync_client.Abc.PmAgent import PmAgentClient
 from xync_schema import models
@@ -88,9 +87,11 @@ class InAgentClient(BaseInAgentClient):
                                     match upd.status:
                                         case StatusApi.created:
                                             logging.info(f"Order {order.id} created at {order.createDate}")
-                                            if upd.side == 1:  # я покупатель - ждем мою оплату
+                                            # сразу уменьшаем доступный остаток монеты/валюты
+                                            await self.money_upd(order_db)
+                                            if upd.side:  # я покупатель - ждем мою оплату
                                                 dest = order.paymentTermList[0].accountNo
-                                                if not re.match(r"^P\d{8,10}$", dest):
+                                                if not re.match(r"^([Pp])\d{8,10}$", dest):
                                                     continue
                                                 await order_db.fetch_related("ad__pair_side__pair", "cred__pmcur__cur")
                                                 await self.send_payment(order_db, dest)
@@ -115,28 +116,17 @@ class InAgentClient(BaseInAgentClient):
                                                         accepted_at=datetime.now(timezone.utc),
                                                     ),
                                                     order=order_db,
+                                                    # pm_id=order_db.cred.pmcur.pm_id,
                                                     pmid=tid,
                                                 )
                                                 if not is_new:
                                                     continue
-                                                await order_db.fetch_related("ad__pair_side__pair")
-                                                async with in_transaction():
-                                                    # добавляем остаток монеты
-                                                    ass = await models.Asset.get(
-                                                        addr__coin_id=order_db.ad.pair_side.pair.coin_id,
-                                                        addr__actor=self.agent_client.actor,
-                                                    )
-                                                    ass.free -= int(order_db.amount / order_db.ad.price)
-                                                    await ass.save(update_fields=["free"])
-                                                    # обновляем остаток валюты
-                                                    fiat = await models.Fiat.get(cred_id=order_db.cred_id)
-                                                    fiat.amount += order_db.amount
-                                                    await fiat.save(update_fields=["amount"])
-                                                    # отправляем деньги
-                                                    self.agent_client.api.release_assets(orderId=upd.id)
-                                                    logging.info(
-                                                        f"Order {order.id} created, paid before #{tid}:{am} at {order.createDate}, and RELEASED at {datetime.now()}"
-                                                    )
+
+                                                # !!! ОТПРАВЛЯЕМ ДЕНЬГИ !!!
+                                                self.agent_client.api.release_assets(orderId=upd.id)
+                                                logging.info(
+                                                    f"Order {order.id} created, paid before #{tid}:{am} at {order.createDate}, and RELEASED at {datetime.now()}"
+                                                )
                                             elif upd.side == 1:  # я покупатель - ждем мою оплату
                                                 continue  # logging.warning(f"Order {order.id} PAID at {datetime.now()}: {int_am}")
                                             else:
@@ -144,30 +134,7 @@ class InAgentClient(BaseInAgentClient):
                                             # todo: check is always canceling
                                             # await order_db.update_from_dict({"status": OrderStatus.canceled}).save()
                                             # logging.info(f"Order {order.id} canceled at {datetime.now()}")
-                                        case StatusApi.appealed:
-                                            # todo: appealed by WHO? щас наугад стоит by_seller
-                                            await order_db.update_from_dict(
-                                                {
-                                                    "status": OrderStatus.appealed_by_seller,
-                                                    "appealed_at": datetime.fromtimestamp(
-                                                        float(order.updateDate) / 1000
-                                                    ),
-                                                }
-                                            ).save()
-                                            logging.info(f"Order {order.id} appealed at {order_db.appealed_at}")
-                                        case StatusApi.canceled:
-                                            await order_db.update_from_dict({"status": OrderStatus.canceled}).save()
-                                            logging.info(f"Order {order.id} canceled at {datetime.now()}")
-                                        case StatusApi.completed:
-                                            await order_db.update_from_dict(
-                                                {
-                                                    "status": OrderStatus.completed,
-                                                    "confirmed_at": datetime.fromtimestamp(
-                                                        float(order.updateDate) / 1000
-                                                    ),
-                                                }
-                                            ).save()
-                                            logging.info(f"Order {order.id} completed at {order_db.confirmed_at}")
+
                                         case StatusApi.wait_for_seller:
                                             if order_db.status == OrderStatus.paid:
                                                 continue
@@ -180,6 +147,35 @@ class InAgentClient(BaseInAgentClient):
                                                 }
                                             ).save()
                                             logging.info(f"Order {order.id} payed at {order_db.payed_at}")
+
+                                        case StatusApi.appealed:
+                                            # todo: appealed by WHO? щас наугад стоит by_seller
+                                            await order_db.update_from_dict(
+                                                {
+                                                    "status": OrderStatus.appealed_by_seller,
+                                                    "appealed_at": datetime.fromtimestamp(
+                                                        float(order.updateDate) / 1000
+                                                    ),
+                                                }
+                                            ).save()
+                                            logging.info(f"Order {order.id} appealed at {order_db.appealed_at}")
+
+                                        case StatusApi.canceled:
+                                            await order_db.update_from_dict({"status": OrderStatus.canceled}).save()
+                                            logging.info(f"Order {order.id} canceled at {datetime.now()}")
+                                            await self.money_upd(order_db)
+
+                                        case StatusApi.completed:
+                                            await order_db.update_from_dict(
+                                                {
+                                                    "status": OrderStatus.completed,
+                                                    "confirmed_at": datetime.fromtimestamp(
+                                                        float(order.updateDate) / 1000
+                                                    ),
+                                                }
+                                            ).save()
+                                            await self.money_upd(order_db)
+
                                         case _:
                                             logging.warning(f"Order {order.id} UNKNOWN STATUS {datetime.now()}")
                                 case "COUNT_DOWN":
@@ -244,8 +240,45 @@ class InAgentClient(BaseInAgentClient):
                     if not upd:
                         logging.warning(data, "NOT PROCESSED UPDATE")
 
+    async def money_upd(self, order_db: models.Order):
+        # обновляем остаток монеты
+        await order_db.fetch_related("ad__pair_side__pair", "cred")
+        ass = await models.Asset.get(
+            addr__coin_id=order_db.ad.pair_side.pair.coin_id, addr__actor=self.agent_client.actor
+        )
+        # обновляем остаток валюты
+        fiat = await models.Fiat.get(
+            cred__person_id=self.agent_client.actor.person_id, cred__pmcur_id=order_db.cred.pmcur_id
+        ).prefetch_related("cred__pmcur__pm")
+        fee = round(order_db.amount * (fiat.cred.pmcur.pm.fee or 0) * 0.0001)
+        im_seller = order_db.ad.pair_side.is_sell == (_im_maker := order_db.ad.maker_id == self.agent_client.actor.id)
+        # k = int(im_seller) * 2 - 1  # im_seller: 1, im_buyer: -1
+        if order_db.status == OrderStatus.created:
+            if im_seller:
+                ass.free -= order_db.quantity
+                ass.freeze += order_db.quantity
+            else:  # я покупатель
+                fiat.amount -= order_db.amount + fee
+        elif order_db.status == OrderStatus.completed:
+            if im_seller:
+                fiat.amount += order_db.amount
+            else:  # я покупатель
+                ass.free += order_db.quantity
+                ass.freeze -= order_db.quantity
+        elif order_db.status == OrderStatus.canceled:
+            if im_seller:
+                ass.free += order_db.quantity
+                ass.freeze -= order_db.quantity
+            else:  # я покупатель
+                fiat.amount += order_db.amount + fee
+        else:
+            logging.exception(order_db.id, f"STATUS: {order_db.status.name}")
+        await ass.save(update_fields=["free", "freeze"])
+        await fiat.save(update_fields=["amount"])
+        logging.info(f"Order #{order_db.id} {order_db.status.name}. Fiat: {fiat.amount}, Asset: {ass.free}")
+
     async def send_payment(self, order_db: models.Order, dest):
-        if order_db.status not in (OrderStatus.created, OrderStatus.requested):
+        if order_db.status != OrderStatus.created:
             return
         fmt_am = round(order_db.amount * 10**-2, 2)
         pma, cur = await self.get_pma_by_pmex(order_db)
@@ -267,12 +300,6 @@ class InAgentClient(BaseInAgentClient):
             order_db.status = OrderStatus.paid
             order_db.payed_at = datetime.now(timezone.utc)
             await order_db.save()
-            # добавляем остаток монеты
-            ass = await models.Asset.get(
-                addr__coin_id=order_db.ad.pair_side.pair.coin_id, addr__actor=self.agent_client.actor
-            )
-            ass.free += int(order_db.amount / order_db.ad.price)
-            await ass.save(update_fields=["free"])
             # отправляем деньги
             tid, img, rest_amount = await pma.send(dest=dest, amount=fmt_am, cur=cur)
             # создаем перевод в бд
@@ -281,8 +308,6 @@ class InAgentClient(BaseInAgentClient):
                 order=order_db,
                 pmid=tid,
             )
-            # обновляем остаток валюты
-            await models.Fiat.update_or_create({"amount": rest_amount * 100}, cred_id=order_db.cred_id)
             # отправляем продавцу чек
             if res := self.agent_client.api.upload_chat_file(upload_file=f"tmp/{dest}.png").get("result"):
                 self.agent_client.api.send_chat_message(
@@ -290,7 +315,7 @@ class InAgentClient(BaseInAgentClient):
                 )
             logging.info(f"Order {order_db.exid} PAID at {datetime.now()}: {fmt_am}!")
 
-    async def get_pma_by_cdex(self, order: OrderFull) -> tuple[PmAgentClient | None, CredEx] | None:
+    async def get_pma_by_cdex(self, order: OrderFull) -> tuple[PmAgentClient | None, models.CredEx] | None:
         cdxs = await models.CredEx.filter(
             ex=self.agent_client.ex_client.ex,
             exid__in=[ptl.id for ptl in order.paymentTermList],
@@ -340,7 +365,7 @@ async def main():
         # await cl.agent_client.export_my_ads()
         payeer_cl = Client(actor.person.user.username_id)
         for pma in actor.person.user.pm_agents:
-            cl.pmacs[pma.pm_id] = await payeer_cl.start(await async_playwright().start(), True)
+            cl.pmacs[pma.pm_id] = await payeer_cl.start(await async_playwright().start(), False)
 
         _ = await cl.start_listen()
         await cl.agent_client.close()
