@@ -16,7 +16,7 @@ class Topic(IntEnum):
 
 class Status(IntEnum):
     deleted = 40  # order canceled
-    created = 10  # waiting for buyer to pay
+    created = 10
     appealable = 20  # waiting for seller to release
     canceled = 40
     completed = 50  # order finished
@@ -26,9 +26,19 @@ class Status(IntEnum):
     paid = 50
     rejected = 40
     request_canceled = 40
-    requested = 10
     seller_appeal_disputed_by_buyer = 30
-    ws = 1
+
+
+class StatusApi(IntEnum):
+    created = 1
+    wait_for_buyer = 10  # ws_canceled
+    wait_for_seller = 20
+    appealed = 30
+    canceled = 40
+    completed = 50
+    hotswap_cancelled = 80
+    objectioning = 100
+    waiting_for_objection = 110
 
 
 class OrderRequest(BaseModel):
@@ -287,7 +297,7 @@ class _BaseChange(BaseModel):
     userId: int
     makerUserId: int
     id: str
-    status: Status
+    status: StatusApi
     createDate: int
     side: int
     appealedTimes: int
@@ -322,7 +332,7 @@ class Receive(_BaseMsg):
 class Read(_BaseMsg):
     readAmount: int
     read: Literal["111", "101"]
-    orderStatus: Status
+    orderStatus: StatusApi
 
 
 class SellerCancelChange(BaseModel):
